"""
Файлы __init__.py необходимы, чтобы Python рассматривал каталоги как
содержащие пакеты; это сделано для предотвращения непреднамеренного
скрытия действительными модулями каталогов с общим именем, например,
строки, которые появляются позже в пути поиска модулей
"""
